@@ -12,7 +12,7 @@ echo $ver $orig_tar $tardir $wd
 tar xf $orig_tar -C $wd 
 srcdir=$wd/*
 
-for subdir in funtools\* sla tcl8.\* tcllib-\* tk8.\* tkimg\* signal_ext\* \
+for subdir in funtools\* tcl8.\* tcllib-\* tk8.\* tkimg\* signal_ext\* \
               tktable\* tkcon-\* tclxml-\* wcssubs-\* xpa-\* \
               zip-\* zlib-\* compilers ast-\* zvfs ; do
     rm -rf $srcdir/$subdir
